@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2020 Stefan Widgren
+## Copyright (C) 2015 -- 2021 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -200,13 +200,6 @@ check_error(res, "Invalid model.")
 res <- assertError(.Call(SimInf:::SIR_run, "SIR", NULL))
 check_error(res, "Invalid model.")
 
-## Check events method
-res <- assertError(events())
-check_error(res, "Missing 'model' argument.")
-
-res <- assertError(events(5))
-check_error(res, "'model' argument is not a 'SimInf_model'.")
-
 model <- SIR(u0     = u0_SIR(),
              tspan  = seq_len(365 * 4),
              events = events_SIR(),
